@@ -71,6 +71,11 @@ define('PHPMYADMIN', true);
  */
 require_once './libraries/vendor_config.php';
 
+/**
+ * Load gettext functions.
+ */
+require_once GETTEXT_INC;
+
 /**
  * Activate autoloader
  */
@@ -143,6 +148,8 @@ $variables_whitelist = array (
     'PMA_PHP_SELF',
     'variables_whitelist',
     'key',
+    /* gettext globals */
+    'text_domains', 'default_domain', 'LC_CATEGORIES', 'EMULATEGETTEXT', 'CURRENTLOCALE',
 );
 
 foreach (get_defined_vars() as $key => $value) {
@@ -471,11 +478,6 @@ if (PMA_isValid($_REQUEST['sql_query'])) {
 /******************************************************************************/
 /* loading language file                       LABEL_loading_language_file    */
 
-/**
- * Load gettext functions.
- */
-require_once GETTEXT_INC;
-
 /**
  * lang detection is done here
  */
