@@ -7,6 +7,8 @@
  *
  * @package PhpMyAdmin
  */
+use PMA\libraries\Message;
+
 if (! defined('PHPMYADMIN')) {
     exit;
 }
@@ -15,8 +17,6 @@ if (! defined('PHPMYADMIN')) {
  * String handling (security)
  */
 require_once 'libraries/string.lib.php';
-require_once 'libraries/String.class.php';
-$PMA_String = new PMA_String();
 
 /**
  * checks given $var and returns it if valid, or $default of not valid
@@ -28,15 +28,15 @@ $PMA_String = new PMA_String();
  * echo PMA_ifSetOr($_REQUEST['db'], ''); // ''
  * // $_REQUEST['sql_query'] not set
  * echo PMA_ifSetOr($_REQUEST['sql_query']); // null
- * // $cfg['ForceSSL'] not set
- * echo PMA_ifSetOr($cfg['ForceSSL'], false, 'boolean'); // false
- * echo PMA_ifSetOr($cfg['ForceSSL']); // null
- * // $cfg['ForceSSL'] set to 1
- * echo PMA_ifSetOr($cfg['ForceSSL'], false, 'boolean'); // false
- * echo PMA_ifSetOr($cfg['ForceSSL'], false, 'similar'); // 1
- * echo PMA_ifSetOr($cfg['ForceSSL'], false); // 1
- * // $cfg['ForceSSL'] set to true
- * echo PMA_ifSetOr($cfg['ForceSSL'], false, 'boolean'); // true
+ * // $cfg['EnableFoo'] not set
+ * echo PMA_ifSetOr($cfg['EnableFoo'], false, 'boolean'); // false
+ * echo PMA_ifSetOr($cfg['EnableFoo']); // null
+ * // $cfg['EnableFoo'] set to 1
+ * echo PMA_ifSetOr($cfg['EnableFoo'], false, 'boolean'); // false
+ * echo PMA_ifSetOr($cfg['EnableFoo'], false, 'similar'); // 1
+ * echo PMA_ifSetOr($cfg['EnableFoo'], false); // 1
+ * // $cfg['EnableFoo'] set to true
+ * echo PMA_ifSetOr($cfg['EnableFoo'], false, 'boolean'); // true
  * </code>
  *
  * @param mixed &$var    param to check
@@ -163,7 +163,7 @@ function PMA_isValid(&$var, $type = 'length', $compare = null)
     if ($type === 'length' || $type === 'scalar') {
         $is_scalar = is_scalar($var);
         if ($is_scalar && $type === 'length') {
-            return (bool) /*overload*/mb_strlen($var);
+            return (bool) mb_strlen($var);
         }
         return $is_scalar;
     }
@@ -221,9 +221,9 @@ function PMA_fatalError(
     }
 
     if (! empty($GLOBALS['is_ajax_request']) && $GLOBALS['is_ajax_request']) {
-        $response = PMA_Response::getInstance();
-        $response->isSuccess(false);
-        $response->addJSON('message', PMA_Message::error($error_message));
+        $response = PMA\libraries\Response::getInstance();
+        $response->setRequestStatus(false);
+        $response->addJSON('message', PMA\libraries\Message::error($error_message));
     } else {
         $error_message = strtr($error_message, array('<br />' => '[br]'));
 
@@ -246,8 +246,8 @@ function PMA_fatalError(
         } else {
             $error_header = 'Error';
         }
-        $lang = $GLOBALS['available_languages'][$GLOBALS['lang']][1];
-        $dir = $GLOBALS['text_dir'];
+        $lang = isset($GLOBALS['lang']) ? $GLOBALS['lang'] : 'en';
+        $dir = isset($GLOBALS['text_dir']) ? $GLOBALS['text_dir'] : 'ltr';
 
         // on fatal errors it cannot hurt to always delete the current session
         if ($delete_session
@@ -341,8 +341,8 @@ function PMA_warnMissingExtension($extension, $fatal = false, $extra = '')
 function PMA_getTableCount($db)
 {
     $tables = $GLOBALS['dbi']->tryQuery(
-        'SHOW TABLES FROM ' . PMA_Util::backquote($db) . ';',
-        null, PMA_DatabaseInterface::QUERY_STORE
+        'SHOW TABLES FROM ' . PMA\libraries\Util::backquote($db) . ';',
+        null, PMA\libraries\DatabaseInterface::QUERY_STORE
     );
     if ($tables) {
         $num_tables = $GLOBALS['dbi']->numRows($tables);
@@ -402,104 +402,6 @@ function PMA_getRealSize($size = 0)
     return $size;
 } // end function PMA_getRealSize()
 
-/**
- * merges array recursive like array_merge_recursive() but keyed-values are
- * always overwritten.
- *
- * array PMA_arrayMergeRecursive(array $array1[, array $array2[, array ...]])
- *
- * @return array   merged array
- *
- * @see     http://php.net/array_merge
- * @see     http://php.net/array_merge_recursive
- */
-function PMA_arrayMergeRecursive()
-{
-    switch(func_num_args()) {
-    case 0 :
-        return false;
-    case 1 :
-        // when does that happen?
-        return func_get_arg(0);
-    case 2 :
-        $args = func_get_args();
-        if (! is_array($args[0]) || ! is_array($args[1])) {
-            return $args[1];
-        }
-        foreach ($args[1] as $key2 => $value2) {
-            if (isset($args[0][$key2]) && !is_int($key2)) {
-                $args[0][$key2] = PMA_arrayMergeRecursive(
-                    $args[0][$key2], $value2
-                );
-            } else {
-                // we erase the parent array, otherwise we cannot override
-                // a directive that contains array elements, like this:
-                // (in config.default.php)
-                // $cfg['ForeignKeyDropdownOrder']= array('id-content','content-id');
-                // (in config.inc.php)
-                // $cfg['ForeignKeyDropdownOrder']= array('content-id');
-                if (is_int($key2) && $key2 == 0) {
-                    unset($args[0]);
-                }
-                $args[0][$key2] = $value2;
-            }
-        }
-        return $args[0];
-    default :
-        $args = func_get_args();
-        $args[1] = PMA_arrayMergeRecursive($args[0], $args[1]);
-        array_shift($args);
-        return call_user_func_array('PMA_arrayMergeRecursive', $args);
-    }
-}
-
-/**
- * calls $function for every element in $array recursively
- *
- * this function is protected against deep recursion attack CVE-2006-1549,
- * 1000 seems to be more than enough
- *
- * @param array    &$array             array to walk
- * @param callable $function           function to call for every array element
- * @param bool     $apply_to_keys_also whether to call the function for the keys also
- *
- * @return void
- *
- * @see http://www.php-security.org/MOPB/MOPB-02-2007.html
- * @see http://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2006-1549
- */
-function PMA_arrayWalkRecursive(&$array, $function, $apply_to_keys_also = false)
-{
-    static $recursive_counter = 0;
-    $walked_keys = array();
-
-    if (++$recursive_counter > 1000) {
-        PMA_fatalError(__('possible deep recursion attack'));
-    }
-    foreach ($array as $key => $value) {
-        if (isset($walked_keys[$key])) {
-            continue;
-        }
-        $walked_keys[$key] = true;
-
-        if (is_array($value)) {
-            PMA_arrayWalkRecursive($array[$key], $function, $apply_to_keys_also);
-        } else {
-            $array[$key] = $function($value);
-        }
-
-        if ($apply_to_keys_also && is_string($key)) {
-            $new_key = $function($key);
-            if ($new_key != $key) {
-                $array[$new_key] = $array[$key];
-                unset($array[$key]);
-                $walked_keys[$new_key] = true;
-            }
-        }
-    }
-    $recursive_counter--;
-}
-
 /**
  * boolean phpMyAdmin.PMA_checkPageValidity(string &$page, array $whitelist)
  *
@@ -521,20 +423,20 @@ function PMA_checkPageValidity(&$page, $whitelist)
         return true;
     }
 
-    $_page = /*overload*/mb_substr(
+    $_page = mb_substr(
         $page,
         0,
-        /*overload*/mb_strpos($page . '?', '?')
+        mb_strpos($page . '?', '?')
     );
     if (in_array($_page, $whitelist)) {
         return true;
     }
 
     $_page = urldecode($page);
-    $_page = /*overload*/mb_substr(
+    $_page = mb_substr(
         $_page,
         0,
-        /*overload*/mb_strpos($_page . '?', '?')
+        mb_strpos($_page . '?', '?')
     );
     if (in_array($_page, $whitelist)) {
         return true;
@@ -582,34 +484,34 @@ function PMA_getenv($var_name)
  * @param string $uri         the header to send
  * @param bool   $use_refresh whether to use Refresh: header when running on IIS
  *
- * @return boolean  always true
+ * @return void
  */
 function PMA_sendHeaderLocation($uri, $use_refresh = false)
 {
-    if (PMA_IS_IIS && /*overload*/mb_strlen($uri) > 600) {
+    if (PMA_IS_IIS && mb_strlen($uri) > 600) {
         include_once './libraries/js_escape.lib.php';
-        PMA_Response::getInstance()->disable();
+        PMA\libraries\Response::getInstance()->disable();
 
-        include_once './libraries/Template.class.php';
-
-        echo PMA\Template::get('header_location')
+        echo PMA\libraries\Template::get('header_location')
             ->render(array('uri' => $uri));
 
         return;
     }
 
+    $response = PMA\libraries\Response::getInstance();
+
     if (SID) {
-        if (/*overload*/mb_strpos($uri, '?') === false) {
-            header('Location: ' . $uri . '?' . SID);
+        if (mb_strpos($uri, '?') === false) {
+            $response->header('Location: ' . $uri . '?' . SID);
         } else {
             $separator = PMA_URL_getArgSeparator();
-            header('Location: ' . $uri . $separator . SID);
+            $response->header('Location: ' . $uri . $separator . SID);
         }
         return;
     }
 
     session_write_close();
-    if (headers_sent()) {
+    if ($response->headersSent()) {
         if (function_exists('debug_print_backtrace')) {
             echo '<pre>';
             debug_print_backtrace();
@@ -624,9 +526,9 @@ function PMA_sendHeaderLocation($uri, $use_refresh = false)
     // results in a blank page
     // but we need it when coming from the cookie login panel)
     if (PMA_IS_IIS && $use_refresh) {
-        header('Refresh: 0; ' . $uri);
+        $response->header('Refresh: 0; ' . $uri);
     } else {
-        header('Location: ' . $uri);
+        $response->header('Location: ' . $uri);
     }
 }
 
@@ -860,15 +762,16 @@ function PMA_isAllowedDomain($url)
         $_SERVER['SERVER_NAME'],
         /* phpMyAdmin domains */
         'wiki.phpmyadmin.net', 'www.phpmyadmin.net', 'phpmyadmin.net',
+        'demo.phpmyadmin.net',
         'docs.phpmyadmin.net',
         /* mysql.com domains */
         'dev.mysql.com','bugs.mysql.com',
-        /* drizzle.org domains */
-        'www.drizzle.org',
         /* mariadb domains */
         'mariadb.org',
         /* php.net domains */
         'php.net',
+        /* sourceforge.net domain */
+        'sourceforge.net',
         /* Github domains*/
         'github.com','www.github.com',
         /* Following are doubtful ones. */
@@ -879,7 +782,7 @@ function PMA_isAllowedDomain($url)
         'ronaldbradford.com',
         'xaprb.com',
     );
-    if (in_array(/*overload*/mb_strtolower($domain), $domainWhiteList)) {
+    if (in_array(mb_strtolower($domain), $domainWhiteList)) {
         return true;
     }
 
@@ -888,7 +791,7 @@ function PMA_isAllowedDomain($url)
 
 
 /**
- * Adds JS code snippets to be displayed by the PMA_Response class.
+ * Adds JS code snippets to be displayed by the PMA\libraries\Response class.
  * Adds a newline to each snippet.
  *
  * @param string $str Js code to be added (e.g. "token=1234;")
@@ -897,7 +800,7 @@ function PMA_isAllowedDomain($url)
  */
 function PMA_addJSCode($str)
 {
-    $response = PMA_Response::getInstance();
+    $response = PMA\libraries\Response::getInstance();
     $header   = $response->getHeader();
     $scripts  = $header->getScripts();
     $scripts->addCode($str);
@@ -905,7 +808,7 @@ function PMA_addJSCode($str)
 
 /**
  * Adds JS code snippet for variable assignment
- * to be displayed by the PMA_Response class.
+ * to be displayed by the PMA\libraries\Response class.
  *
  * @param string $key    Name of value to set
  * @param mixed  $value  Value to set, can be either string or array of strings
@@ -949,13 +852,13 @@ function PMA_previewSQL($query_data)
         $retval .= __('No change');
     } elseif (is_array($query_data)) {
         foreach ($query_data as $query) {
-            $retval .= PMA_Util::formatSql($query);
+            $retval .= PMA\libraries\Util::formatSql($query);
         }
     } else {
-        $retval .= PMA_Util::formatSql($query_data);
+        $retval .= PMA\libraries\Util::formatSql($query_data);
     }
     $retval .= '</div>';
-    $response = PMA_Response::getInstance();
+    $response = PMA\libraries\Response::getInstance();
     $response->addJSON('sql_data', $retval);
     exit;
 }
@@ -971,7 +874,7 @@ function PMA_emptyRecursive($value)
 {
     $empty = true;
     if (is_array($value)) {
-        PMA_arrayWalkRecursive(
+        array_walk_recursive(
             $value,
             function ($item) use (&$empty) {
                 $empty = $empty && empty($item);
@@ -1019,6 +922,56 @@ function PMA_setGlobalDbOrTable($param)
     }
 }
 
+/**
+ * PATH_INFO could be compromised if set, so remove it from PHP_SELF
+ * and provide a clean PHP_SELF here
+ *
+ * @return void
+ */
+function PMA_cleanupPathInfo()
+{
+    global $PMA_PHP_SELF, $_PATH_INFO;
+
+    $PMA_PHP_SELF = PMA_getenv('PHP_SELF');
+    $_PATH_INFO = PMA_getenv('PATH_INFO');
+    if (! empty($_PATH_INFO) && ! empty($PMA_PHP_SELF)) {
+        $path_info_pos = mb_strrpos($PMA_PHP_SELF, $_PATH_INFO);
+        $pathLength = $path_info_pos + mb_strlen($_PATH_INFO);
+        if ($pathLength === mb_strlen($PMA_PHP_SELF)) {
+            $PMA_PHP_SELF = mb_substr($PMA_PHP_SELF, 0, $path_info_pos);
+        }
+    }
+    $PMA_PHP_SELF = htmlspecialchars($PMA_PHP_SELF);
+}
+
+/**
+ * Checks that required PHP extensions are there.
+ * @return void
+ */
+function PMA_checkExtensions()
+{
+    /**
+     * Warning about mbstring.
+     */
+    if (! function_exists('mb_detect_encoding')) {
+        PMA_warnMissingExtension('mbstring', true);
+    }
+
+    /**
+     * We really need this one!
+     */
+    if (! function_exists('preg_replace')) {
+        PMA_warnMissingExtension('pcre', true);
+    }
+
+    /**
+     * JSON is required in several places.
+     */
+    if (! function_exists('json_encode')) {
+        PMA_warnMissingExtension('json', true);
+    }
+}
+
 /* Compatibility with PHP < 5.6 */
 if(! function_exists('hash_equals')) {
     function hash_equals($a, $b) {
